@@ -156,8 +156,22 @@ class Reader:
             return d
 
         if "23andMe" in first_line:
-            d = self.read_23andme(file, compression)
-        elif "Ancestry" in first_line:
+            # some 23andMe files have separate alleles
+            if comments.endswith(
+                "# rsid\tchromosome\tposition\tallele1\tallele2\n"
+            ) or comments.endswith(
+                "# rsid\tchromosome\tposition\tallele1\tallele2\r\n"
+            ):
+                d = self.read_23andme(file, compression, joined=False)
+            # some 23andMe files have a combined genotype
+            elif comments.endswith(
+                "# rsid\tchromosome\tposition\tgenotype\n"
+            ) or comments.endswith("# rsid\tchromosome\tposition\tgenotype\r\n"):
+                d = self.read_23andme(file, compression, joined=True)
+            # something we havent seen before and can't handle
+            else:
+                return d
+        elif "AncestryDNA" in first_line:
             d = self.read_ancestry(file, compression)
         elif first_line.startswith("RSID"):
             d = self.read_ftdna(file, compression)
@@ -186,6 +200,8 @@ class Reader:
         elif first_line.startswith("[Header]"):
             # Global Screening Array, includes SANO and CODIGO46
             d = self.read_gsa(file, compression, comments)
+        elif "Circle" in first_line:
+            d = self.read_circledna(file, compression)
 
         # detect build from comments if build was not already detected from `read` method
         if not d["build"]:
@@ -430,7 +446,7 @@ class Reader:
 
         return {"snps": df, "source": source, "phased": phased, "build": build}
 
-    def read_23andme(self, file, compression):
+    def read_23andme(self, file, compression, joined=True):
         """Read and parse 23andMe file.
 
         https://www.23andme.com
@@ -447,15 +463,18 @@ class Reader:
         """
 
         def parser():
+            if joined:
+                columnnames = ["rsid", "chrom", "pos", "genotype"]
+            else:
+                columnnames = ["rsid", "chrom", "pos", "allele1", "allele2"]
             df = pd.read_csv(
                 file,
                 comment="#",
                 sep="\t",
-                na_values="--",
-                names=["rsid", "chrom", "pos", "genotype"],
+                na_values=["--", "-"],
+                names=columnnames,
                 compression=compression,
             )
-            df = df.dropna(subset=["rsid", "chrom", "pos"])
             # turn number numbers into string numbers
             df["chrom"] = df["chrom"].map(
                 {
@@ -508,6 +527,12 @@ class Reader:
                     "MT": "MT",
                 }
             )
+            if not joined:
+                # stick separate alleles together
+                df["genotype"] = df["allele1"] + df["allele2"]
+                del df["allele1"]
+                del df["allele2"]
+            df = df.dropna(subset=["rsid", "chrom", "pos"])
             df = df.astype(dtype=NORMALIZED_DTYPES)
             df = df.set_index("rsid")
             return (df,)
@@ -1116,6 +1141,60 @@ class Reader:
 
         return self.read_helper("DNA.Land", parser)
 
+    def read_circledna(self, file, compression):
+        """Read and parse CircleDNA file.
+
+        https://circledna.com/
+
+        Notes
+        -----
+        This method attempts to read and parse a whole exome file, optionally compressed
+        with gzip or zip. Some assumptions are made throughout this process:
+
+            * SNPs that are not annotated with an RSID are skipped
+            * Insertions and deletions are skipped
+
+        Parameters
+        ----------
+        file : str or bytes
+            path to file or bytes to load
+
+        Returns
+        -------
+        dict
+            result of `read_helper`
+        """
+
+        def parser():
+            rs_chunks = []
+            with pd.read_csv(
+                file,
+                comment="#",
+                sep="\t",
+                chunksize=10000,
+                names=["rsid", "chrom", "pos", "genotype"],
+                compression=compression,
+            ) as reader:
+                for chunk in reader:
+
+                    # filter for SNPs with rsids
+                    tmp = chunk.loc[
+                        (chunk.rsid.str.startswith("rs"))
+                        & (chunk.genotype.str.len() == 3)
+                    ]
+                    if len(tmp) > 0:
+                        rs_chunks.append(tmp)
+
+            df = pd.concat(rs_chunks)
+            df.chrom = df.chrom.str[3:]
+            df.genotype = df.genotype.apply(lambda x: "".join(x.split("/")))
+            df = df.astype(NORMALIZED_DTYPES)
+            df.set_index("rsid", inplace=True)
+
+            return (df,)
+
+        return self.read_helper("CircleDNA", parser)
+
     def read_snps_csv(self, file, comments, compression):
         """Read and parse CSV file generated by ``snps``.
 
